# Alibi-Detect runtime for MLServer

This package provides a MLServer runtime compatible with Alibi-Detect.

## Usage

You can install the runtime, alongside `mlserver`, as:

```bash
pip install mlserver mlserver-alibi-detect
```

For further information on how to use MLServer with Alibi-Detect, you can check
out this [worked out example](../../docs/examples/alibi-detect/README.md).
